@@ -35,12 +35,12 @@ mo_location = LOCALE_DIR
 
 # Lets tell those details to gettext
 #  (nothing to change here for you)
-gettext.install(True, localedir=None, unicode=1)
-
-gettext.find(APP_NAME, mo_location)
-
-gettext.textdomain(APP_NAME)
-
-gettext.bind_textdomain_codeset(APP_NAME, "UTF-8")
-
-language = gettext.translation(APP_NAME, mo_location, languages=languages, fallback=True)
\ No newline at end of file
+# gettext.install(True, localedir=None, unicode=1)
+#
+# gettext.find(APP_NAME, mo_location)
+#
+# gettext.textdomain(APP_NAME)
+#
+# gettext.bind_textdomain_codeset(APP_NAME, "UTF-8")
+#
+# language = gettext.translation(APP_NAME, mo_location, languages=languages, fallback=True)
\ No newline at end of file
