@@ -36,7 +36,7 @@ from core import utils
 from core import paths
 from core import configs
 from core import gs
-
+from core.backports import six
 # record that imports-done timestamp
 importsDoneTimestamp = time.time()
 
@@ -172,7 +172,8 @@ class ModRana(object):
     if self.args.u:
       try:
         self.GUIString = self.args.u.split(":")[0]
-      except Exception, e:
+      except Exception:
+        e = sys.exc_info()[1]
         print('modRana: splitting the GUI string failed')
         print(e)
     else: # no ID specified
@@ -295,19 +296,22 @@ class ModRana(object):
     that was removed are not loaded by mistake.
     This situation shouldn't really happen if modRana is installed from a package,
     as all .pyc files are purged during package upgrade and regenerated."""
-    return filter(
-      lambda x:
-      x[0:len(prefix)] == prefix
-      and
-      (x[-4:] not in ('.pyc', '.pyo')), os.listdir(folder)
+    moduleNames = filter(
+      lambda x: x[0:len(prefix)] == prefix, os.listdir(folder)
     )
+    # remove the extension
+    moduleNames = map(lambda x: os.path.splitext(x)[0], moduleNames)
+    # return a set of unique module names
+    # * like this, two module names will not be returned if there are
+    # both py and pyc files
+    return set(moduleNames)
 
   def _listAvailableDeviceModulesByID(self):
     moduleNames = self._getModuleNamesFromFolder(DEVICE_MODULES_FOLDER, prefix='device_')
     # remove the device_ prefix and return the results
-    # NOTE: .pyc & .pyo should be removed already in _getModuleNamesFromFolder()
-    # laos sort the module names alphabetically
-    return sorted(map(lambda x: x[7:].replace('.py', ''), moduleNames))
+    # NOTE: .py, .pyc & .pyo should be removed already in _getModuleNamesFromFolder()
+    # also sort the module names alphabetically
+    return sorted(map(lambda x: x[7:], moduleNames))
 
   def _listAvailableGUIModulesByID(self):
     return self._getModuleNamesFromFolder(GUI_MODULES_FOLDER)
@@ -325,9 +329,11 @@ class ModRana(object):
       self.m[modRanaName] = module
       print( " * %s: %s (%1.2f ms)" % (modRanaName, self.m[modRanaName].__doc__, (1000 * (time.clock() - startM))) )
       return module
-    except Exception, e:
+    except Exception:
+      e = sys.exc_info()[1]
       print( "modRana: module: %s/%s failed to load" % (importName, modRanaName) )
       print(e)
+      print("traceback:")
       traceback.print_exc(file=sys.stdout) # find what went wrong
       return None
     finally:
@@ -668,8 +674,9 @@ class ModRana(object):
     reloaded on startup)
     ASSUMPTION: keys are strings of length>=1"""
     try:
-      return dict((k, v) for k, v in inputDict.iteritems() if k[0] != '#')
-    except Exception, e:
+      return dict((k, v) for k, v in six.iteritems(inputDict) if k[0] != '#')
+    except Exception:
+      e = sys.exc_info()[1]
       print(
         'options: error while filtering options\nsome nonpersistent keys might have been left in\nNOTE: keys should be strings of length>=1\n',
         e)
@@ -679,7 +686,7 @@ class ModRana(object):
     """save the persistent dictionary to file"""
     print("modRana: saving options")
     try:
-      f = open(self.paths.getOptionsFilePath(), "w")
+      f = open(self.paths.getOptionsFilePath(), "wb")
       # remove keys marked as nonpersistent
       self.d['keyModifiers'] = self.keyModifiers
       d = self._removeNonPersistentOptions(self.d)
@@ -688,14 +695,15 @@ class ModRana(object):
       print("modRana: options successfully saved")
     except IOError:
       print("modRana: Can't save options")
-    except Exception, e:
+    except Exception:
+      e = sys.exc_info()[1]
       print("modRana: saving options failed:", e)
 
   def _loadOptions(self):
     """load the persistent dictionary from file"""
     print("modRana: loading options")
     try:
-      f = open(self.paths.getOptionsFilePath(), "r")
+      f = open(self.paths.getOptionsFilePath(), "rb")
       newData = marshal.load(f)
       f.close()
       purgeKeys = ["fix"]
@@ -705,7 +713,8 @@ class ModRana(object):
       for k, v in newData.items():
         self.set(k, v)
       success = True
-    except Exception, e:
+    except Exception:
+      e = sys.exc_info()[1]
       print("modRana: exception while loading saved options:\n%s" % e)
       #TODO: a yes/no dialog for clearing (renaming with timestamp :) the corrupted options file (options.bin)
       success = False
