@@ -191,13 +191,17 @@ class DeviceModule(RanaModule):
     """return device specific map folder or None if default should be used"""
     return None
 
+  def getRoutingDataFolderPath(self):
+    """return device specific map folder or None if default should be used"""
+    return None
+
   def getPOIFolderPath(self):
     """return device specific POI folder or None if default should be used"""
     return None
 
   def getLogFolderPath(self):
     """default path is handled through the options module"""
-    None
+    return None
 
   def needsQuitButton(self):
     """On some platforms (Android chroot) applications
