@@ -23,7 +23,10 @@ import os
 import sys
 import re
 import traceback
-import cStringIO
+try:
+  from StringIO import StringIO # python 2
+except ImportError:
+  from io import StringIO # python 3
 from pprint import pprint
 
 # PySide
@@ -42,6 +45,9 @@ from modules.gui_modules.gui_qml import drawing
 from modules.gui_modules.gui_qml import wrappers
 from modules.gui_modules.gui_qml import list_models
 from core.fix import Fix
+from core import signal
+from core.backports import six
+from core import constants
 
 global globe
 
@@ -83,6 +89,7 @@ class QMLGUI(GUIModule):
     # some constants
     self.msLongPress = 400
     self.centeringDisableThreshold = 2048
+    self.firstTimeSignal = signal.Signal()
     size = (800, 480) # initial window size
 
     # window state
@@ -120,7 +127,7 @@ class QMLGUI(GUIModule):
     #    self.view.setResizeMode(QDeclarativeView.SizeViewToRootObject)
 
     # add image providers
-    self.iconProvider = IconImageProvider()
+    self.iconProvider = IconImageProvider(self)
     self.view.engine().addImageProvider("icons", self.iconProvider)
     # add tiles provider
     self.tilesProvider = TileImageProvider(self)
@@ -128,7 +135,7 @@ class QMLGUI(GUIModule):
 
     rc = self.view.rootContext()
     # make core modRana functionality accessible from QML
-    modRanaCore = ModRana(self.modrana)
+    modRanaCore = ModRana(self.modrana, self)
     rc.setContextProperty("modrana", modRanaCore)
     # make options accessible from QML
     options = Options(self.modrana)
@@ -146,8 +153,8 @@ class QMLGUI(GUIModule):
     tiles = MapTiles(self)
     rc.setContextProperty("mapTiles", tiles)
     # make map layers accessible from QML
-    tiles = MapLayers(self)
-    rc.setContextProperty("mapLayers", tiles)
+    layers = MapLayers(self)
+    rc.setContextProperty("mapLayers", layers)
 
     # make constants accessible
     self.constants = self.getConstants()
@@ -176,6 +183,9 @@ class QMLGUI(GUIModule):
     #register list models
     self._registerListModels()
 
+    # trigger the first time signal
+    self.firstTimeSignal()
+
   def getIDString(self):
     return "QML"
 
@@ -314,6 +324,7 @@ class QMLGUI(GUIModule):
       wrappedGroupList = map(
         lambda x: wrappers.MapLayerGroupWrapper(x), ml.getGroupList(sort=True)
       )
+      wrappedGroupList = list(wrappedGroupList)
       self.layersListModel = list_models.BaseListModel(wrappedGroupList)
       self._registerListModel("mapLayersModel", self.layersListModel)
 
@@ -429,7 +440,9 @@ class Modules(QtCore.QObject):
         function = getattr(m, functionName)
         result = function()
         return result
-      except Exception, e:
+      except Exception:
+        import sys
+        e = sys.exc_info()[1]
         print("QML GUI: calling function %s on module %s failed" % (functionName, moduleName))
         print(e)
         return None
@@ -442,13 +455,31 @@ class IconImageProvider(QDeclarativeImageProvider):
   """the IconImageProvider class provides icon images to the QML layer as
   QML does not seem to handle .. in the url very well"""
 
-  def __init__(self):
+  def __init__(self, gui):
     QDeclarativeImageProvider.__init__(self, QDeclarativeImageProvider.ImageType.Image)
+    self.gui = gui
 
   def requestImage(self, iconPath, size, requestedSize):
     try:
+
       #TODO: theme name caching ?
-      f = open('themes/%s' % iconPath, 'r')
+      themeFolder = self.gui.modrana.paths.getThemesFolderPath()
+      fullIconPath = os.path.join(themeFolder, iconPath)
+
+      # the path is constructed like this in QML
+      # so we can safely just split it like this
+      splitPath = iconPath.split("/")
+      if not os.path.exists(fullIconPath):
+        if splitPath[0] == constants.DEFAULT_THEME_ID:
+          # already on default theme and icon path does not exist
+          return None
+        else:  # try to get the icon from default theme
+          splitPath[0] = constants.DEFAULT_THEME_ID
+          fullIconPath = os.path.join(themeFolder, *splitPath)
+          if not os.path.exists(fullIconPath):
+            # icon not found even in the default theme
+            return None
+      f = open(fullIconPath, 'rb')
       #      print("ICON")
       #      print(iconPath)
       #      print(size)
@@ -457,10 +488,14 @@ class IconImageProvider(QDeclarativeImageProvider):
       img.loadFromData(f.read())
       f.close()
       return img
-    except Exception, e:
+    except Exception:
+      import sys
+      e = sys.exc_info()[1]
       print("QML GUI: icon image provider: loading icon failed")
       print(e)
       print(os.path.join('themes', iconPath))
+      print("Traceback:")
+      traceback.print_exc(file=sys.stdout) # find what went wrong
 
 class TileImageProvider(QDeclarativeImageProvider):
   """
@@ -482,8 +517,8 @@ class TileImageProvider(QDeclarativeImageProvider):
     the tile info should look like this:
     layerID/zl/x/y
     """
-    #    print("IMAGE REQUESTED")
-    #    print(tileInfo)
+    #print("IMAGE REQUESTED")
+    #print(tileInfo)
     try:
       # split the string provided by QML
       split = tileInfo.split("/")
@@ -495,20 +530,23 @@ class TileImageProvider(QDeclarativeImageProvider):
       # get the tile from the tile module
       tileData = self.gui._mapTiles.getTile(layerId, z, x, y)
       if not tileData:
+        # print("NO TILEDATA")
         return None
 
       # create a file-like object
-      f = cStringIO.StringIO(tileData)
+      # f = StringIO(tileData)
       # create image object
       img = QImage()
       # lod the image from in memory buffer
-      img.loadFromData(f.read())
+      # img.loadFromData(f.read())
+      img.loadFromData(tileData)
       # cleanup
-      f.close()
+      # f.close()
       #print("OK")
       return img
-
-    except Exception, e:
+    except Exception:
+      import sys
+      e = sys.exc_info()[1]
       print("QML GUI: icon image provider: loading tile failed")
       print(e)
       print(tileInfo)
@@ -566,7 +604,7 @@ class MapLayers(QtCore.QObject):
     # map layers module is not yet loaded)
     if self._wrappedLayers is None:
       self._wrappedLayers = {}
-      for layerId, layer in self.gui._mapLayers.getLayerDict().iteritems():
+      for layerId, layer in six.iteritems(self.gui._mapLayers.getLayerDict()):
         self.wrappedLayers[layerId] = wrappers.MapLayerWrapper(layer)
     return self._wrappedLayers
 
@@ -717,7 +755,7 @@ class GPSDataWrapper(QtCore.QObject):
     #    self.modrana.connect('target-changed', self._on_target_changed)
     self.modrana.watch('locationUpdated', self._posChangedCB)
 
-    pos = self.modrana.get('pos', None)
+    pos = self.modrana.get('pos', constants.DEFAULT_COORDINATES)
     speed = self.modrana.get('speed', 0)
     bearing = self.modrana.get('bearing', 0)
     elevation = self.modrana.get('elevation', 0)
@@ -741,7 +779,9 @@ class GPSDataWrapper(QtCore.QObject):
     fix = None
     try:
       fix = self.gui._location.getFix()
-    except Exception, e:
+    except Exception:
+      import sys
+      e = sys.exc_info()[1]
       print("gui_qml: can't get fix object from location module")
       print(e)
     if fix:
@@ -780,7 +820,6 @@ class GPSDataWrapper(QtCore.QObject):
   def _gps_mode(self):
     return self.gps_mode
 
-
   data = QtCore.Property(QtCore.QObject, _gps_data, notify=changed)
   lastGoodFix = QtCore.Property(QtCore.QObject, _gps_last_good_fix, notify=changed)
   hasFix = QtCore.Property(bool, _gps_has_fix, notify=changed)
@@ -792,11 +831,13 @@ class ModRana(QtCore.QObject):
   core modRana functionality
   """
 
-  def __init__(self, modrana):
+  def __init__(self, modrana, gui):
     QtCore.QObject.__init__(self)
     self.modrana = modrana
+    self.gui = gui
     self.modrana.watch("mode", self._modeChangedCB)
     self.modrana.watch("theme", self._themeChangedCB)
+    self._theme = Theme(gui)
 
   # mode
 
@@ -814,12 +855,15 @@ class ModRana(QtCore.QObject):
 
   # theme
 
-  def _getTheme(self):
+  def _getThemeId(self):
     return self.modrana.get('theme', "default")
 
-  def _setTheme(self, newTheme):
+  def _setThemeId(self, newTheme):
     return self.modrana.set('theme', newTheme)
 
+  def _getTheme(self):
+    return self._theme
+
   themeChanged = Signal()
 
   def _themeChangedCB(self, *args):
@@ -829,7 +873,92 @@ class ModRana(QtCore.QObject):
   # properties
 
   mode = QtCore.Property(str, _getMode, _setMode, notify=modeChanged)
-  theme = QtCore.Property(str, _getTheme, _setTheme, notify=themeChanged)
+  theme_id = QtCore.Property(str, _getThemeId, _setThemeId, notify=themeChanged)
+  theme = QtCore.Property(QtCore.QObject, _getTheme, notify=themeChanged)
+
+class Theme(QtCore.QObject):
+  """modRana themes"""
+  def __init__(self, gui):
+    QtCore.QObject.__init__(self)
+    self.gui = gui
+    # connect to the first time signal
+    self.gui.firstTimeSignal.connect(self._firstTimeCB)
+
+  themeChanged = Signal()
+
+  def _firstTimeCB(self):
+    # we need the them module
+    self.themeModule = self.gui.m.get('theme')
+    self.theme = self.themeModule.theme
+    self.colors = ColorsWrapper(self.theme)
+    # connect to the theme changed signal
+    self.themeModule.themeChanged.connect(self._themeChangedCB)
+
+  def _themeChangedCB(self, newTheme):
+    self.theme = newTheme
+    self.colors.reloadTheme(self.theme)
+    self.themeChanged.emit()
+
+  def _getThemeId(self):
+    return self.theme.id
+
+  def _setThemeId(self, newTheme):
+    return self.modrana.set('theme', newTheme)
+
+  def _getThemeName(self):
+    return self.theme.name
+
+  def _getColor(self):
+    return self.colors
+
+  id = QtCore.Property(str, _getThemeId, _setThemeId, notify=themeChanged)
+  name = QtCore.Property(str, _getThemeName, notify=themeChanged)
+  color = QtCore.Property(QtCore.QObject, _getColor, notify=themeChanged)
+
+class ColorsWrapper(QtCore.QObject):
+  """Wrapper for modRana theme colors"""
+  def __init__(self, theme):
+    QtCore.QObject.__init__(self)
+    self.t = theme
+
+  colorsChanged = Signal()
+
+  def reloadTheme(self, theme):
+    """Replace the current theme with a new one
+    and emit the changed signal"""
+    self.t = theme
+    self.colorsChanged.emit()
+
+  def _main_fill(self):
+    return self.t.getColor("main_fill", "#92aaf3")
+
+  def _icon_grid_toggled(self):
+    return self.t.getColor("icon_grid_toggled", "#c6d1f3")
+
+  def _icon_button_normal(self):
+    return self.t.getColor("icon_button_normal", "#c6d1f3")
+
+  def _icon_button_toggled(self):
+    return self.t.getColor("icon_button_toggled", "#3c60fa")
+
+  def _icon_button_text(self):
+    return self.t.getColor("icon_button_text", "black")
+
+  def _page_background(self):
+    return self.t.getColor("page_background", "black")
+
+  def _page_header_text(self):
+    return self.t.getColor("page_header_text", "black")
+
+  main_fill = QtCore.Property(str, _main_fill, notify=colorsChanged)
+  icon_grid_toggled = QtCore.Property(str, _icon_grid_toggled, notify=colorsChanged)
+  icon_button_normal = QtCore.Property(str, _icon_button_normal, notify=colorsChanged)
+  icon_button_toggled = QtCore.Property(str, _icon_button_toggled, notify=colorsChanged)
+  icon_button_text = QtCore.Property(str, _icon_button_text, notify=colorsChanged)
+  page_header_text = QtCore.Property(str, _page_header_text, notify=colorsChanged)
+  page_background = QtCore.Property(str, _page_background, notify=colorsChanged)
+
+
 
 class Options(QtCore.QObject):
   """make options available to QML and integrable as a property"""
