@@ -40,14 +40,12 @@ def getModule(m,d,i):
     return CronGTK(m,d,i)
 
 class Cron(RanaModule):
-  """A timing and scheduling module for modRana"""
+  """A timing and scheduling module for modRana
 
-  """
   -> this is an abstract class
   that specifies and interface for concrete implementations
-  """
 
-  """Why is there a special module for timing ?
+  Why is there a special module for timing ?
      The reason is twofold:
      Toolkit independence and power saving/monitoring.
 
@@ -69,12 +67,13 @@ class Cron(RanaModule):
     """add a callback that is called once the main loop becomes idle"""
     pass
 
-  def addTimeout(self, callback, timeout, caller, description, args=[]):
+  def addTimeout(self, callback, timeout, caller, description, args=None):
     """the callback will be called timeout + time needed to execute the callback
     and other events"""
+    if not args: args = []
     pass
 
-  def _doTimeout(self, id, callback, args):
+  def _doTimeout(self, timeoutId, callback, args):
     """wrapper about the timeout function, which makes it possible to check
     if a timeout is still in progress from the "outside"
     - like this, the underlying timer should also be easily replaceable
@@ -85,17 +84,17 @@ class Cron(RanaModule):
       # that means it wants to quit the timeout
 
       # stop tracking
-      self.removeTimeout(id)
+      self.removeTimeout(timeoutId)
       # propagate the quit signal
       return False
     else:
       return True # just run the loop
 
-  def removeTimeout(self, id):
+  def removeTimeout(self, timeoutId):
     """remove timeout with a given id"""
     pass
 
-  def modifyTimeout(self, id, newTimeout):
+  def modifyTimeout(self, timeoutId, newTimeout):
     """modify the duration of a timeout in progress"""
     pass
 
@@ -115,9 +114,9 @@ class CronGTK(Cron):
     """get an unique id for timing related request that can be
     returned to the callers and used as a handle
     TODO: can int overflow in Python ?"""
-    id = self.nextId
+    timeoutId = self.nextId
     self.nextId+=1
-    return id
+    return timeoutId
 
   def addIdle(self, callback, args):
     """add a callback that is called once the main loop becomes idle"""
@@ -127,35 +126,35 @@ class CronGTK(Cron):
     """the callback will be called timeout + time needed to execute the callback
     and other events"""
     if not args: args = []
-    id = self._getID()
-    realId = gobject.timeout_add(timeout, self._doTimeout, id, callback, args)
+    timeoutId = self._getID()
+    realId = gobject.timeout_add(timeout, self._doTimeout, timeoutId, callback, args)
     timeoutTuple = (callback, args, timeout, caller, description, realId)
     with self.dataLock:
-      self.cronTab['timeout'][id] = timeoutTuple
-    return id
+      self.cronTab['timeout'][timeoutId] = timeoutTuple
+    return timeoutId
 
-  def removeTimeout(self, id):
+  def removeTimeout(self, timeoutId):
     """remove timeout with a given id"""
     with self.dataLock:
-      if id in self.cronTab['timeout'].keys():
-        (callback, args, timeout, caller, description, realId) = self.cronTab['timeout'][id]
-        del self.cronTab['timeout'][id]
+      if timeoutId in self.cronTab['timeout'].keys():
+        (callback, args, timeout, caller, description, realId) = self.cronTab['timeout'][timeoutId]
+        del self.cronTab['timeout'][timeoutId]
         gobject.source_remove(realId)
       else:
-        print("cron: can't remove timeout, wrong id: ", id)
+        print("cron: can't remove timeout, wrong id: ", timeoutId)
 
-  def modifyTimeout(self, id, newTimeout):
+  def modifyTimeout(self, timeoutId, newTimeout):
     """modify the duration of a timeout in progress"""
     with self.dataLock:
-      if id in self.cronTab['timeout'].keys():
+      if timeoutId in self.cronTab['timeout'].keys():
         # load the timeout description
-        (callback, args, timeout, caller, description, realId) = self.cronTab['timeout'][id]
+        (callback, args, timeout, caller, description, realId) = self.cronTab['timeout'][timeoutId]
         gobject.source_remove(realId) # remove the old timeout
-        realId = gobject.timeout_add(newTimeout, self._doTimeout, id, callback, args) # new timeout
+        realId = gobject.timeout_add(newTimeout, self._doTimeout, timeoutId, callback, args) # new timeout
         # update the timeout description
-        self.cronTab['timeout'][id] = (callback, args, newTimeout, caller, description, realId)
+        self.cronTab['timeout'][timeoutId] = (callback, args, newTimeout, caller, description, realId)
       else:
-        print("cron: can't modify timeout, wrong id: ", id)
+        print("cron: can't modify timeout, wrong id: ", timeoutId)
 
 class CronQt(Cron):
   """A Qt timing and scheduling module for modRana"""
@@ -173,9 +172,9 @@ class CronQt(Cron):
     TODO: can int overflow in Python ?
     TODO: id recycling ?"""
     with self.dataLock:
-      id = self.nextId
+      timeoutId = self.nextId
       self.nextId+=1
-      return id
+      return timeoutId
 
   def addIdle(self, callback, args):
     """add a callback that is called once the main loop becomes idle"""
@@ -189,43 +188,43 @@ class CronQt(Cron):
     # create and configure the timer
     timer = QtCore.QTimer()
 #    timer.setInterval(timeout)
-    id = self._getID()
-    """create a new function that calls the callback processing function
-     with thh provided arguments"""
-    handleThisTimeout = lambda: self._doTimeout(id, callback, args)
+    timeoutId = self._getID()
+    # create a new function that calls the callback processing function
+    # with thh provided arguments"""
+    handleThisTimeout = lambda: self._doTimeout(timeoutId, callback, args)
     # connect this function to the timeout
     timer.timeout.connect(handleThisTimeout)
     # store timer data
-    timeoutTuple = (callback, args, timeout, caller, description, id, timer)
+    timeoutTuple = (callback, args, timeout, caller, description, timeoutId, timer)
     with self.dataLock:
-      self.cronTab['timeout'][id] = timeoutTuple
+      self.cronTab['timeout'][timeoutId] = timeoutTuple
     # start the timer
     timer.start(timeout)
     # return the id
-    return id
+    return timeoutId
 
-  def removeTimeout(self, id):
+  def removeTimeout(self, timeoutId):
     """remove timeout with a given id"""
     with self.dataLock:
-      if id in self.cronTab['timeout'].keys():
-        (callback, args, timeout, caller, description, id, timer) = self.cronTab['timeout'][id]
+      if timeoutId in self.cronTab['timeout'].keys():
+        (callback, args, timeout, caller, description, timeoutId, timer) = self.cronTab['timeout'][timeoutId]
         timer.stop()
-        del self.cronTab['timeout'][id]
+        del self.cronTab['timeout'][timeoutId]
       else:
-        print("cron: can't remove timeout, wrong id: ", id)
+        print("cron: can't remove timeout, wrong id: ", timeoutId)
 
-  def modifyTimeout(self, id, newTimeout):
+  def modifyTimeout(self, timeoutId, newTimeout):
     """modify the duration of a timeout in progress"""
     with self.dataLock:
-      if id in self.cronTab['timeout'].keys():
+      if timeoutId in self.cronTab['timeout'].keys():
         # load the timeout data
-        (callback, args, timeout, caller, description, id, timer) = self.cronTab['timeout'][id]
+        (callback, args, timeout, caller, description, timeoutId, timer) = self.cronTab['timeout'][timeoutId]
         # reset the timeout duration
         timer.setInterval(newTimeout)
         # update the timeout data
-        self.cronTab['timeout'][id] = (callback, args, newTimeout, caller, description, id, timer)
+        self.cronTab['timeout'][timeoutId] = (callback, args, newTimeout, caller, description, timeoutId, timer)
       else:
-        print("cron: can't modify timeout, wrong id: ", id)
+        print("cron: can't modify timeout, wrong id: ", timeoutId)
 
 #  def _addInfo(self, id, info):
 #    """add a message for a timeout handler to read"""
