@@ -24,7 +24,10 @@ from core import utils
 import math
 import os
 import glob
-import cPickle
+try:
+  import cPickle as pickle # Python 2
+except ImportError:
+  import pickle # Python 3
 import shutil
 from time import clock
 from time import gmtime, strftime
@@ -47,7 +50,7 @@ class LoadTracklogs(RanaModule):
   def firstTime(self):
     self._createBasicFolderStructure()
 
-  def handleMessage(self, message, type, args):
+  def handleMessage(self, message, messageType, args):
     if message == 'loadActive':
       # load the active tracklog
       path = self.get('activeTracklogPath', None)
@@ -66,7 +69,9 @@ class LoadTracklogs(RanaModule):
           try:
             self.loadTracklog(path)
             print("tracklog successfully loaded")
-          except Exception, e:
+          except Exception:
+            import sys
+            e = sys.exc_info()[1]
             print("loading tracklog failed")
             print("path: %s" % path)
             print(e)
@@ -101,8 +106,8 @@ class LoadTracklogs(RanaModule):
     self._getTFSubPath("logs")
     self._getTFSubPath("online")
     self._getTFSubPath("misc")
-    """if there is no example folder, create it
-    and copy example tracklogs into it"""
+    # if there is no example folder, create it
+    # and copy example tracklogs into it
     tfp = self.modrana.paths.getTracklogsFolderPath()
     examplesDestinationPath = os.path.join(tfp,'examples')
     if not os.path.exists(examplesDestinationPath):
@@ -126,9 +131,11 @@ class LoadTracklogs(RanaModule):
     start = clock()
     try:
       f = open(self.getTracklogCachePath(), 'r')
-      self.cache = cPickle.load(f)
+      self.cache = pickle.load(f)
       f.close()
-    except Exception, e:
+    except Exception:
+      import sys
+      e = sys.exc_info()[1]
       print("loadTracklogs: loading cache from file failed")
       print(e)
       self.cache = {}
@@ -141,10 +148,10 @@ class LoadTracklogs(RanaModule):
     for g in garbage:
       del self.cache[g]
 
-  def deleteTrackFromCache(self, file):
+  def deleteTrackFromCache(self, tracklogFile):
     # self explanatory
-    if file in self.cache:
-      del self.cache[file]
+    if tracklogFile in self.cache:
+      del self.cache[tracklogFile]
 
 #  def renameTracklog(track, newName=None):
 #    """rename a given tracklog file"""
@@ -341,9 +348,11 @@ class LoadTracklogs(RanaModule):
     try:
       print(self.getTracklogCachePath())
       f = open(self.getTracklogCachePath(), 'w')
-      cPickle.dump(self.cache, f)
+      pickle.dump(self.cache, f)
       f.close()
-    except Exception, e:
+    except Exception:
+      import sys
+      e = sys.exc_info()[1]
       print("loadTracklogs: can't store tracklog data to cache, tracklogs will be loaded from files next time")
       print("exception: %r" % e)
 
@@ -386,7 +395,9 @@ class LoadTracklogs(RanaModule):
 
     try:
       file = open(path, 'r')
-    except Exception ,e:
+    except Exception:
+      import sys
+      e = sys.exc_info()[1]
       print("loading tracklog failed: %s" % path)
       print(e)
 
@@ -400,7 +411,9 @@ class LoadTracklogs(RanaModule):
       # lets assume we have only GPX 1.1 files TODO: 1.1 and 1.0
       try:
         track.import_locations(file, "1.1") # load a gpx file into it
-      except Exception, e:
+      except Exception:
+        import sys
+        e = sys.exc_info()[1]
         print("loading tracklog failed:\n%s" % e)
         if notify:
           self.sendMessage('notification:loading tracklog failed#2')
@@ -461,7 +474,9 @@ class LoadTracklogs(RanaModule):
         f = open(os.path.join(path,filename), 'w')
         xmlTree.write(f)
         f.close()
-      except Exception, e:
+      except Exception:
+        import sys
+        e = sys.exc_info()[1]
         print("loadTracklogs: saving tracklog failed")
         print("exception: %s" % e)
         self.sendMessage('notification:Error: saving tracklog failed#3')
@@ -523,12 +538,10 @@ class Tracklog():
     self.trackpointsList = trackpointsList # here will be the actual list of trackpoints
     self.filename = filename # the filename as used when loading the list from file
     self.type = type
-    """
-  tracklog types: (for now)
-  'gpx'= a GPX tracklog
-  'kml'= a KML tracklog
-  'nmea' = a NMEA log file
-  """
+    # tracklog types: (for now)
+    # 'gpx'= a GPX tracklog
+    # 'kml'= a KML tracklog
+    # 'nmea' = a NMEA log file
     self.tracklogName = filename # custom name for the tracklog, by default the filename
     self.tracklogDescription = "" # description of the tracklog
 
@@ -638,8 +651,8 @@ class GPXTracklog(Tracklog):
       middle = minElevation + (difference/2)
       firstElevation = float(firstPoint.elevation)
       lastElevation = float(lastPoint.elevation)
-      """because there are many possible statistics about a given route with elevation,
-      we will store them in a dictionary, so new ones can be quickly added as needed"""
+      # because there are many possible statistics about a given route with elevation,
+      # we will store them in a dictionary, so new ones can be quickly added as needed
 #      self.routeInfo['firstPoint'] = firstPoint
 #      self.routeInfo['lastPoint'] = lastPoint
 #      self.routeInfo['maxElevationPoint'] = maxElevationPoint
