@@ -40,7 +40,7 @@ class MapView(RanaModule):
     self.modrana.watch('mapGridColor', self._drawGridColorCB, runNow=True)
     self.modrana.watch('mapGridLabels', self._drawGridLabelsCB, runNow=True)
 
-  def handleMessage(self, message, type, args):
+  def handleMessage(self, message, messageType, args):
     z = self.get('z', 15)
     if message == 'zoomIn':
       newZ = z + 1
@@ -76,17 +76,19 @@ class MapView(RanaModule):
 
     elif message:
       try:
-        list = message.split(' ')
-        lat = float(list[1])
-        lon = float(list[2])
-        if len(list) == 4:
-          zoom = int(list[3])
+        cList = message.split(' ')
+        lat = float(cList[1])
+        lon = float(cList[2])
+        if len(cList) == 4:
+          zoom = int(cList[3])
         else:
           zoom = z
         proj = self.m.get('projection', None)
         self.set("centred",False) # turn off centering before moving screen to the coordinates
         proj.recentre(lat, lon, zoom)
-      except Exception, e:
+      except Exception:
+        import sys
+        e = sys.exc_info()[1]
         print("mapView: cant recenter coordinates")
         print(e)
   
@@ -113,10 +115,8 @@ class MapView(RanaModule):
       (lat,lon) = pos
       self.set('map_centre', pos)
       z = int(self.get('z', 15))
-      x,y = proj.ll2xy(lat,lon)
       if not self.d.has_key('viewport'):
         return False
-      (sx,sy,sw,sh) = self.get('viewport')
       # the shift amount represents a percentage of the distance from screen center
       # to an edge:
       # center+---------->|edge
@@ -165,7 +165,9 @@ class MapView(RanaModule):
       try:
         c = color.Color(newKey, (newKey, 1.0))
         self.gridColor = c.getCairoColor()
-      except Exception, e:
+      except Exception:
+        import sys
+        e = sys.exc_info()[1]
         print('mapView: color parsing failed')
         print(e)
 
