@@ -19,6 +19,8 @@
 #---------------------------------------------------------------------------
 from modules.base_module import RanaModule
 from core import utils
+from core.backports import six
+from core import constants
 
 # identifies item as a group
 GROUP_IDENTIFIER = "groupIdentifier"
@@ -324,7 +326,7 @@ class Options(RanaModule):
     choices['groupName'] = group
 
     newOption = [title, variable, choices, group, default]
-    if self.options.has_key(group):
+    if group in self.options:
       self.options[group][2].append(newOption)
       self.keyDefault[variable] = default
     else:
@@ -416,7 +418,7 @@ class Options(RanaModule):
       groups = mapLayers.getGroupList()
 
       # sort the groups in alphabetical order by label
-      groups.sort(key=lambda group: group.label)
+      groups = sorted(groups, key=lambda group: group.label)
 
       # assign layers to groups
       for group in groups:
@@ -438,7 +440,7 @@ class Options(RanaModule):
 
         # create (layerId, label, icon) tuples,
         # reuse the variable:
-        groupLayers = map(lambda x: (x.id, x.label, x.icon, defaultBA), groupLayers)
+        groupLayers = list(map(lambda x: (x.id, x.label, x.icon, defaultBA), groupLayers))
 
         # append their counter to the group name
         name = "%s (%d)" % (name, len(groupLayers))
@@ -449,7 +451,7 @@ class Options(RanaModule):
       # append layers without group right after groups in the list
       nonGroupLayers = mapLayers.getLayersWithoutGroup()
       # sort the groups in alphabetical order by label
-      nonGroupLayers.sort(key=lambda group: group.label)
+      nonGroupLayers = sorted(nonGroupLayers, key=lambda group: group.label)
       # convert to option format
       nonGroupLayers = map(
         lambda x: {'item':(x, x.label, x.icon, defaultBA)}, nonGroupLayers)
@@ -608,15 +610,17 @@ class Options(RanaModule):
         addBoolOpt("Redraw when on dashboard", "redrawOnDashboard", group, False)
 
       # ** themes
-      icons = self.m.get('icons', None)
-      if icons:
+      theme = self.m.get('theme', None)
+      if theme:
         group = addGroup("Themes", "themes", catView, "generic")
-        defaultTheme = icons.defaultTheme
-        themeList = icons.getThemeList()
-        # check if current theme exists
+        defaultTheme = constants.DEFAULT_THEME_ID
+        themeList = theme.getAvailableThemeIds()
+        # check if current theme as set in options exists
         currentTheme = self.get('currentTheme', None)
         if currentTheme is not None:
           if currentTheme not in themeList:
+            print("options: theme with id %s is not available,\n"
+                  "switching back to default theme" % currentTheme)
             self.set('currentTheme', defaultTheme) # theme not valid, reset to default
 
         themeChangedMessage = "icons:themeChanged"
@@ -625,8 +629,8 @@ class Options(RanaModule):
         addOpt("Current theme", "currentTheme",
           nameValueList,
           group,
-          defaultTheme)
-
+          defaultTheme
+        )
 
     # ** units
     group = addGroup("formats#Units and", "units", catView, "generic")
@@ -1069,7 +1073,7 @@ class Options(RanaModule):
       for option in options[2]:
         (title, variable, choices, category, default) = option
         if default is not None:
-          if not self.d.has_key(variable):
+          if not variable in self.d:
             self.set(variable, default)
 
   def _removeNonPersistent(self, inputDict):
@@ -1078,8 +1082,10 @@ class Options(RanaModule):
     reloaded on startup)
     ASSUMPTION: keys are strings of length>=1"""
     try:
-      return dict((k, v) for k, v in inputDict.iteritems() if k[0] != '#')
-    except Exception, e:
+      return dict((k, v) for k, v in six.iteritems(inputDict) if k[0] != '#')
+    except Exception:
+      import sys
+      e = sys.exc_info()[1]
       print(
         'options: error while filtering options\nsome nonpersistent keys might have been left in\nNOTE: keys should be strings of length>=1\n'
         , e)
