@@ -20,31 +20,31 @@
 from modules.base_module import RanaModule
 from core.tilenames import *
 from core import geo
+from core.constants import DEFAULT_COORDINATES
 from math import *
 import math
 
+
 def getModule(m,d,i):
   return Projection(m,d,i)
 
 class Projection(RanaModule):
   """Projection code (lat/long to screen conversions)"""
 
-  """
-  HOW DOES IT WORK:
-  - there are basically two modes:
-  * current position tracking
-   => set view + recentre + 2*find edges
-  * map dragging
-   => nudge + 1*find edges
+  # HOW DOES IT WORK:
+  # - there are basically two modes:
+  # * current position tracking
+  #  => set view + recentre + 2*find edges
+  # * map dragging
+  #  => nudge + 1*find edges
 
-  TODO:
-  - why is find edges called twice for position tracking ?
-  - don't redraw the whole map for a small nudge
-   -> currently even for a 1 pixel nudge, the whole screen is redrawn
-  - use a mechanism similar to nudging for faster tracklog drawing
-   -> show the trackpoints so no ll2xy would be needed
+  # TODO:
+  # - why is find edges called twice for position tracking ?
+  # - don't redraw the whole map for a small nudge
+  #  -> currently even for a 1 pixel nudge, the whole screen is redrawn
+  # - use a mechanism similar to nudging for faster tracklog drawing
+  #  -> show the trackpoints so no ll2xy would be needed
 
-  """
   def __init__(self, m, d, i):
     RanaModule.__init__(self, m, d, i)
     
@@ -59,18 +59,15 @@ class Projection(RanaModule):
 
 
   def firstTime(self):
-    # make absolutely sure that centering is turned on
+    # make absolutely sure that centering is turned on on startup
     # otherwise we don't know what to show -> black screen => NOT GOOD :)
 
-    defaultPosition = (49.2, 16.616667) # Brno
-#      (49.233056, 17.666944) # Zlin
-
     pos = self.get("pos", None)
     if pos:
       (lat,lon) = pos # use position from last time
     else: # use default position
-      self.set("pos", defaultPosition) # Brno
-      (lat,lon) = defaultPosition
+      self.set("pos", DEFAULT_COORDINATES) # Brno
+      (lat,lon) = DEFAULT_COORDINATES
 
     self.recentre(lat, lon)
 
@@ -340,7 +337,7 @@ class Projection(RanaModule):
     C = 2*pi*R # circumference of Earth
     degreesPerKm = 360/C # how many degrees is a kilometre
     degreesPerPixel = ((self.N - self.S)/self.h) # how many degrees is a pixel (with current zoom)
-    """we get degrees equivalent from kilometers and then convert it to pixels"""
+    # we get degrees equivalent from kilometers and then convert it to pixels
     return (distanceInKm * degreesPerKm)/degreesPerPixel
 
 # doesnt seem to work correctly
@@ -362,7 +359,7 @@ class Projection(RanaModule):
     (cornerX,cornerY) = self.xy2ll(cornerXpixel, cornerYpixel) # we convert them to projection coordinates
     (anotherCornerXpixel,anotherCornerYpixel) = self.screenPos(1, 1) # we take the coordinates of another corner of the screen
     (anotherCornerX,anotherCornerY) = self.xy2ll(anotherCornerXpixel, anotherCornerYpixel) # we convert them to projection coordinates
-    """radius = diagonal/2"""
+    # radius = diagonal/2
     radius = geo.distance(anotherCornerX, anotherCornerY, cornerX , cornerY)/2.0
     return centreX, centreY, radius # we return the centre coordinates and the radius
 
