@@ -20,10 +20,10 @@
 import traceback
 import sys
 from modules.base_module import RanaModule
-import cPickle
 import os
 import sqlite3
 import csv
+from core.backports.six import u
 
 def getModule(m,d,i):
   return StorePOI(m,d,i)
@@ -52,12 +52,16 @@ class StorePOI(RanaModule):
       try:
         self.db = sqlite3.connect(DBPath)
         print(" @ storePOI: connection to POI db established")
-      except Exception, e:
+      except Exception:
+        import sys
+        e = sys.exc_info()[1]
         print(" @ storePOI: connecting to POI database failed:\n%s" % e)
     else: # create new db
       try:
         self.db = self.createDatabase(DBPath)
-      except Exception, e:
+      except Exception:
+        import sys
+        e = sys.exc_info()[1]
         print(" @ storePOI: creating POI database failed:\n%s" % e)
 
   def disconnectFromDb(self):
@@ -77,17 +81,17 @@ class StorePOI(RanaModule):
     conn.execute('CREATE TABLE poi (poi_id integer PRIMARY KEY, lat real, lon real, label text, desc text, cat_id integer)')
     # load the predefined categories
     # (currently the same ones as in MaemoMapper)
-    defaultCats = [(1, u'Service Station', u'Stations for purchasing fuel for vehicles.', 1),
-                   (2, u'Residence', u'Houses, apartments, or other residences of import.', 1),
-                   (3, u'Restaurant', u'Places to eat or drink.', 1),
-                   (4, u'Shopping/Services', u'Places to shop or acquire services.', 1),
-                   (5, u'Recreation', u'Indoor or Outdoor places to have fun.', 1),
-                   (6, u'Transportation', u'Bus stops, airports, train stations, etc.', 1),
-                   (7, u'Lodging', u'Places to stay temporarily or for the night.', 1),
-                   (8, u'School', u'Elementary schools, college campuses, etc.', 1),
-                   (9, u'Business', u'General places of business.', 1),
-                   (10, u'Landmark', u'General landmarks.', 1),
-                   (11, u'Other', u'Miscellaneous category for everything else.', 1)]
+    defaultCats = [(1, u('Service Station'), u('Stations for purchasing fuel for vehicles.'), 1),
+                   (2, u('Residence'), u('Houses, apartments, or other residences of import.'), 1),
+                   (3, u('Restaurant'), u('Places to eat or drink.'), 1),
+                   (4, u('Shopping/Services'), u('Places to shop or acquire services.'), 1),
+                   (5, u('Recreation'), u('Indoor or Outdoor places to have fun.'), 1),
+                   (6, u('Transportation'), u('Bus stops, airports, train stations, etc.'), 1),
+                   (7, u('Lodging'), u('Places to stay temporarily or for the night.'), 1),
+                   (8, u('School'), u('Elementary schools, college campuses, etc.'), 1),
+                   (9, u('Business'), u('General places of business.'), 1),
+                   (10, u('Landmark'), u('General landmarks.'), 1),
+                   (11, u('Other'), u('Miscellaneous category for everything else.'), 1)]
     for cat in defaultCats:
       conn.execute('insert into category values(?,?,?,?)', cat)
     # commit the changes
@@ -103,9 +107,9 @@ class StorePOI(RanaModule):
       self.db.execute(query,values)
       self.db.commit()
 
-  def deletePOI(self,id):
+  def deletePOI(self,poiId):
     """delete a poi with given ID from the database"""
-    self.db.execute('delete from poi where poi_id=?', [id])
+    self.db.execute('delete from poi where poi_id=?', [poiId])
     self.db.commit()
 
   def getCategories(self):
@@ -156,14 +160,14 @@ class StorePOI(RanaModule):
       return None
 
   class POI(object):
-    """this class represents a POI"""
-    def __init__(self,callback,label,description,lat,lon,catId,id=None):
+    """This class represents a POI"""
+    def __init__(self,callback,label,description,lat,lon,catId,poiId=None):
       self.callback = callback
-      self.id=id
+      self.id=poiId
       self.lat=lat
       self.lon=lon
-      self.label= u'%s' % label
-      self.description= u'%s' % description
+      self.label= u('%s') % label
+      self.description= u('%s') % description
       self.categoryId=catId
 
     def __str__(self):
@@ -230,11 +234,11 @@ class StorePOI(RanaModule):
         menus.addItem('POIDetailTools', 'longitude#edit', 'generic', 'ms:showPOI:editActivePOI:lon')
         menus.addItem('POIDetailTools', 'category#change', 'generic', 'ml:showPOI:setupPOICategoryChooser:showPOI;setCatAndCommit|set:menu:menu#list#POICategoryChooser')
         menus.addItem('POIDetailTools', 'position#set as', 'generic', 'showPOI:centerOnActivePOI|ml:location:setPosLatLon:%f;%f' % (self.lat,self.lon))
-        """just after the point is stored and and its detail menu shows up for the first time,
-        it cant be deleted from the database, because we don't know which index it got :D
-        TODO: find a free index and then store the point on it
-        (make sure no one writes to the database between getting the free index and writing the poi to it)
-        then we would be able to delete even newly created points"""
+        # just after the point is stored and and its detail menu shows up for the first time,
+        # it cant be deleted from the database, because we don't know which index it got :D
+        # TODO: find a free index and then store the point on it
+        # (make sure no one writes to the database between getting the free index and writing the poi to it)
+        # then we would be able to delete even newly created points
         if self.getId():
           menus.addItem('POIDetailTools', 'POI#delete', 'generic', 'showPOI:askDeleteActivePOI')
 
@@ -242,12 +246,12 @@ class StorePOI(RanaModule):
       return [self.id,self.lat,self.lon,self.label,self.description,self.categoryId]
 
     def setName(self, newLabel, commit=True):
-      self.label = u'%s' % newLabel
+      self.label = u('%s') % newLabel
       if commit:
         self.storeToDb()
 
     def setDescription(self, newDescription, commit=True):
-      self.description = u'%s' % newDescription
+      self.description = u('%s') % newDescription
       if commit:
         self.storeToDb()
 
@@ -312,7 +316,9 @@ class StorePOI(RanaModule):
           os.rename(oldPOIPath,renamedOldPOIPath)
           print("storePOI: old POI file moved to: %s" % renamedOldPOIPath)
           self.sendMessage('ml:notification:m:%d old POI imported to category "Other";10' % len(points))
-      except Exception, e:
+      except Exception:
+        import sys
+        e = sys.exc_info()[1]
         print("storePOI: import of old POI failed:\n%s" % e)
 
 
@@ -321,24 +327,27 @@ class StorePOI(RanaModule):
     """load POI from file - depreciated, used sqlite for POI storage"""
     try:
       f = open(path, 'r')
-      points = cPickle.load(f)
+      import pickle
+      points = pickle.load(f)
       f.close()
       return points
-    except Exception, e:
+    except Exception:
+      import sys
+      e = sys.exc_info()[1]
       print("storePOI: loading POI from file failed:\n%s" % e)
       return None
 
-  def handleMessage(self, message, type, args):
-    if type == 'ms' and message == 'deletePOI':
-      """remove a poi with given id from database"""
+  def handleMessage(self, message, messageType, args):
+    if messageType == 'ms' and message == 'deletePOI':
+      # remove a poi with given id from database
       if args:
-        id = int(args)
-        self.deletePOI(id) # remove the poi from database
+        poiId = int(args)
+        self.deletePOI(poiId) # remove the poi from database
         # notify the showPOI module, that it might need to rebuild its menus
         self.sendMessage('showPOI:listMenusDirty')
-    elif type == 'ms' and message == 'setCatAndCommit':
-      """set category and as this is the last needed input,
-         commit the new POI to db"""
+    elif messageType == 'ms' and message == 'setCatAndCommit':
+      # set category and as this is the last needed input,
+      # commit the new POI to db"""
       catId = int(args)
       # set the category to the one the user just selected
       self.tempOnlinePOI.setCategory(catId, commit=False)
@@ -349,9 +358,7 @@ class StorePOI(RanaModule):
       catInfo = self.getCategoryForId(catId)
       catName = catInfo[1]
       POIName = self.tempOnlinePOI.getName()
-      """
-      NOTE: False means the the variable is unset, as None means the map screen
-      """
+      # NOTE: False means the the variable is unset, as None means the map screen
       if self.menuNameAfterStorageComplete == False:
         self.set('menu', 'search#searchResultsItem')
       else:
@@ -360,21 +367,21 @@ class StorePOI(RanaModule):
       self.sendMessage('ml:notification:m:%s has been saved to %s;5' % (POIName, catName))
 
     elif message == "reconnectToDb":
-      """this means, that we need to reconnect the database connection
-         * this is used for example as a notification,
-          that the user changed the default POI db path"""
+      # this means, that we need to reconnect the database connection
+      # * this is used for example as a notification,
+      # that the user changed the default POI db path"""
       self.disconnectFromDb()
       self.connectToDb()
 
     elif message == "dumpToCSV":
-      """dump db to CSV file"""
+      # dump db to CSV file
       self.set('menu', None)
       self.dumpToCSV()
 
   def handleTextEntryResult(self, key, result):
     if key == 'onlineResultName':
-      """like this, the user can edit the name of the
-         result before saving it to POI"""
+      # like this, the user can edit the name of the
+      # result before saving it to POI
       self.tempOnlinePOI.setName(result, commit=False)
       self.sendMessage('ml:notification:m:Select a category for the new POI;3')
       self.sendMessage('ml:showPOI:setupPOICategoryChooser:storePOI;setCatAndCommit')
@@ -410,7 +417,9 @@ class StorePOI(RanaModule):
         CSVDump(path, rows)
 
         self.sendMessage('ml:notification:m:POI exported to: %s;5' % POIFolderPath)
-      except Exception, e:
+      except Exception:
+        import sys
+        e = sys.exc_info()[1]
         print("storePOI: CSV dump failed")
         print(e)
         traceback.print_exc(file=sys.stdout)
@@ -464,10 +473,10 @@ class StorePOI(RanaModule):
 
     try: # it seems, that this entry is no guarantied
       for phoneNumber in result['phoneNumbers']:
-        type = ""
+        numberType = ""
         if phoneNumber['type'] != "":
-          type = " (%s)" % phoneNumber['type']
-        text += "\n%s%s" % (phoneNumber['number'], type)
+          numberType = " (%s)" % phoneNumber['type']
+        text += "\n%s%s" % (phoneNumber['number'], numberType)
     except:
       text += "\n%s" % "no phone numbers found"
 
